==> gerbera-debug-2.1.0-4-x86_64.pkg.tar.zst: usr/src/debug/gerbera/gerbera-2.1.0/src/content/scripting/metafile_parser_script.h <==
/*MT*

    MediaTomb - http://www.mediatomb.cc/

    metafile_parser_script.h - this file is part of MediaTomb.

    Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                       Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>

    Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                            Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                            Leonhard Wimmer <leo@mediatomb.cc>

    Copyright (C) 2016-2024 Gerbera Contributors

    MediaTomb is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2
    as published by the Free Software Foundation.

    MediaTomb is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    version 2 along with MediaTomb; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

    $Id$
*/

/// \file metafile_parser_script.h

#ifndef __METAFILE_PARSER_SCRIPT_H__
#define __METAFILE_PARSER_SCRIPT_H__

#include "parser_script.h"

class MetafileParserScript : public ParserScript {
public:
    MetafileParserScript(const std::shared_ptr<ContentManager>& content, const std::string& parent);
    void processObject(const std::shared_ptr<CdsObject>& obj, const fs::path& path);

    std::pair<std::shared_ptr<CdsObject>, int> createObject2cdsObject(const std::shared_ptr<CdsObject>& origObject, const std::string& rootPath) override;
    bool setRefId(const std::shared_ptr<CdsObject>& cdsObj, const std::shared_ptr<CdsObject>& origObject, int pcdId) override;

protected:
    std::string metafileFunction;

    std::shared_ptr<CdsObject> createObject(const std::shared_ptr<CdsObject>& pcd) override;
    void handleObject2cdsItem(duk_context* ctx, const std::shared_ptr<CdsObject>& pcd, const std::shared_ptr<CdsItem>& item) override;
};

#endif // __METAFILE_PARSER_SCRIPT_H__

==> gerbera-debug-3.0.0-2-x86_64.pkg.tar.zst: usr/src/debug/gerbera/gerbera-3.0.0/src/content/scripting/metafile_parser_script.h <==
/*MT*

    MediaTomb - http://www.mediatomb.cc/

    metafile_parser_script.h - this file is part of MediaTomb.

    Copyright (C) 2005 Gena Batyan <bgeradz@mediatomb.cc>,
                       Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>

    Copyright (C) 2006-2010 Gena Batyan <bgeradz@mediatomb.cc>,
                            Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                            Leonhard Wimmer <leo@mediatomb.cc>

    Copyright (C) 2016-2025 Gerbera Contributors

    MediaTomb is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2
    as published by the Free Software Foundation.

    MediaTomb is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    version 2 along with MediaTomb; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

    $Id$
*/

/// @file content/scripting/metafile_parser_script.h

#ifndef __METAFILE_PARSER_SCRIPT_H__
#define __METAFILE_PARSER_SCRIPT_H__

#include "parser_script.h"

class MetafileParserScript : public ParserScript {
public:
    MetafileParserScript(const std::shared_ptr<Content>& content, const std::string& parent);
    void processObject(const std::shared_ptr<CdsObject>& obj, const fs::path& path);

    std::pair<std::shared_ptr<CdsObject>, int> createObject2cdsObject(const std::shared_ptr<CdsObject>& origObject, const std::string& rootPath) override;
    bool setRefId(const std::shared_ptr<CdsObject>& cdsObj, const std::shared_ptr<CdsObject>& origObject, int pcdId) override;

protected:
    std::string metafileFunction;

    std::shared_ptr<CdsObject> createObject(const std::shared_ptr<CdsObject>& pcd) override;
    void handleObject2cdsItem(duk_context* ctx, const std::shared_ptr<CdsObject>& pcd, const std::shared_ptr<CdsItem>& item) override;
};

#endif // __METAFILE_PARSER_SCRIPT_H__
